// English (reference translation)
// author: Stephan Aßmus <stippi@yellowbites.com>

#include <InterfaceDefs.h>

// addon stuff
extern "C" {
_EXPORT void init_strings(const char* strings[]);
}

// NOTES: Try to be as crisp as possible. If possible, try to make super menu labels
// and sub-items read as one command, ie consider the sub-item label as within the
// context of the super item label.
// Fine tune the alignment of tool tips by manually putting the linebreak character
// '\n' at the best position. You can change the Translation while WonderBrush is running!
// Try to sound professional, prefer passive over active voice. In the English translation,
// I don't follow this myself everywhere, but for example in German it sounds more professional
// to say "Doubleclick opens panel." than to say "Doubleclick to open panel!".
// "opens panel" is also better than to say "will open panel". Keep "professional" in mind.
// If you can still manage to add a certain level of coolness to the formulation, even better! :-)

// IMPORTANT: Translations are compiled as addons during runtime!
// If for some reason WonderBrush doesn't show your translation, it is most likely
// a syntaxt error in the file. Launch WonderBrush from the command line and see what it has to say.
// If you see an error message from GCC, it might be helpful, but be aware that the line number where it failed
// does not reference the correct line number in the original translation, since WonderBrush prepends
// some lines before compiling the addon.

// init_strings
void
init_strings(const char* strings[])
{
	strings[FILE_MENU]			= "Fichier";
	strings[NEW]				= "Nouveau";				// will show up in Canvas menu
	strings[NEW_CANVAS]			= "Nouveau document";			// tool tip
	strings[NEW_LAYER]			= "Nouveau calque";				// these strings were added
	strings[NEW_BRUSH]			= "Nouveau pinceau";				// by request to be able to
	strings[NEW_PALETTE]		= "Nouvelle palette";				// reflect different genders in "New"
	strings[OPEN]				= "Ouvrir";
	strings[LOAD]				= "Charger";
	strings[OPEN_CANVAS]		= "Ouvrir un document";
	strings[SAVE_CANVAS]		= "Enregistrer le projet";
	strings[SAVE]				= "Enregistrer";
	strings[SAVE_AS]			= "Enregistrer sous";
	strings[EXPORT_CANVAS]		= "Exporter le projet";
	strings[EXPORT]				= "Exporter";
	strings[EXPORT_AS]			= "Exporter sous";
	strings[SETUP_PAGE]			= "Mise en page";
	strings[PRINT]				= "Imprimer";
	strings[CLOSE]				= "Fermer";
	strings[CLOSE_CANVAS]		= "Fermer ce document";		// tool tip
	strings[ABOUT]				= "A propos";
	strings[QUIT]				= "Quitter";

	strings[LOADING_FILE]		= "Chargement du fichier:";

	strings[EDIT]				= "Edition";
	strings[UNDO]				= "Annuler";
	strings[REDO]				= "Refaire";

	strings[SETTINGS]			= "Paramètres";
	strings[FULLSCREEN]			= "Plein écran";
	strings[SHOW_GRID]			= "Afficher la grille de pixels";	// if zoomed in far enough,
														// display a grid arround each pixel
	strings[LANGUAGE]			= "Langue";
	strings[CANVAS]				= "Espace de travail";				// ie project, document
	strings[IMAGE]				= "Image";				// ie bitmap
	strings[CLEAR]				= "Nettoyer";
	strings[RESIZE]				= "Redimensionner";				// resize canvas (new resolution)
	strings[ROTATE_90]			= "90°";
	strings[ROTATE_180]			= "180°";
	strings[ROTATE_270]			= "-90°";

	strings[FORMAT]				= "Mode";				// color space of the canvas (RGB, Lab etc)

	strings[CURSOR_SOURCE]		= "Source du curseur";
	strings[BITMAP_SOURCE]		= "Source d'image";

	strings[LAYER]				= "Calque";
	strings[DUPLICATE]			= "Dupliquer";
	strings[MERGE_DOWN]			= "Combiner";			// combining of current layer and the
														// one underneath it
	strings[MERGE_VISIBLE]		= "Combiner les calques visibles";		// combining of all visible layers
	strings[RENAME]				= "Renommer";
	strings[DELETE]				= "Supprimer";
	strings[DELETE_ALL]			= "Tout supprimer";

	// layer blending modes
	strings[MODE]				= "Mode";
	strings[NORMAL]				= "Normal";
	strings[ERASE]				= "Invisible";
	strings[MULTIPLY]			= "Multiplier";
	strings[INVERSE_MULTIPLY]	= "Inverser la multiplication";
	strings[LUMINANCE]			= "Luminance";
	strings[MULTIPLY_ALPHA]		= "Masque";
	strings[MULTIPLY_INVERSE_ALPHA]	= "Inverser le masque";

	strings[HISTORY]			= "Historique";			// as in "modifier stack"
	strings[OBJECT]				= "Objet";				// new name for the "History"
	strings[FREEZE]				= "Assembler";				// renders the result of the modifier stack
														// into one "bitmap modifier" and replaces
														// all previous modifiers (ie, you cannot edit
														// them anymore) by the single bitmap modifier
	strings[CUT]				= "Couper";
	strings[COPY]				= "Copier";
	strings[PASTE]				= "Coller";
	strings[MULTI_PASTE]		= "Coller pour chaque";		// paste one ore more properties to
														// *multiple* objects at once
	strings[REMOVE_ALL]			= "Tout supprimer";

	strings[OBJECT_SELECTION]	= "Select";				// change selection shortcuts
	strings[SELECT_ALL_OBJECTS]	= "All";				// in Object and Property list
	strings[SELECT_NO_OBJECTS]	= "None";
	strings[INVERT_SELECTION]	= "Invert Selection";
	strings[ALL_OBJECTS]		= "All";
	strings[PROPERTY_SELECTION]	= "Selection";
	strings[SELECT_ALL_PROPERTIES] = "Tout selectionner";
	strings[SELECT_NO_PROPERTIES] = "Ne rien selectionner";

	// filters
	strings[ADD_FILTER]			= "Filtres";				// the actual menu
	strings[DROP_SHADOW]		= "Ombre portée";
	strings[GAUSSIAN_BLUR]		= "Flou gaussien";
	strings[INVERT]				= "Inverser";
	strings[BRIGHTNESS]			= "Lumière";
	strings[CONTRAST]			= "Contraste";
	strings[SATURATION]			= "Saturation";
	strings[MOTION_BLUR]		= "Flou directionnel";
	strings[HALFTONE]			= "Tramage";
	strings[DOT]				= "Point";				// mode options of Halftone
	strings[LINE]				= "Ligne";
	strings[DITHER]				= "Reéchantillonner";
	strings[DITHER_FS]			= "Reéchantillonner (FS)";
	strings[DITHER_NC]			= "Reéchantillonner (NK)";
	strings[NOISE]				= "Bruit";
	strings[HUE_SHIFT]			= "Colorisation";			// filter not yet written
	strings[DISPERSION]			= "Dispersion";
	strings[STRENGTH]			= "Renforcer";
	strings[LUMINANCE_ONLY]		= "Luminosité";

	strings[PROPERTY]			= "Propriétés";
	strings[UNKOWN_PROPERTY]	= "<inconnu>";

	strings[SWATCHES]			= "Couleur";			// color palette
	strings[ZOOM]				= "Zoom";
	strings[ALPHA]				= "Opacité";				// keep this as short as possible
	strings[ALPHA_CHANNEL]		= "Opacité";		// used for properties
	strings[COLOR]				= "Couleur";				// used for properties
	// brush options
	strings[OPACITY]			= "Opacité";
	strings[MIN_OPACITY]		= "Op. mini";			// property label (keep short)
	strings[DYN_OPACITY]		= "Op. dyn";			// property label (keep short)
	strings[RADIUS]				= "Rayon";
	strings[MIN_RADIUS]			= "Ray. mini";			// property label (keep short)
	strings[DYN_RADIUS]			= "Ray. dyn";			// property label (keep short)
	strings[HARDNESS]			= "Lissage";			// controls brush shape (soft...hard)
	strings[MIN_HARDNESS]		= "Liss. mini";			// property label (keep short)
	strings[DYN_HARDNESS]		= "Liss. dyn";			// property label (keep short)
	strings[SPACING]			= "Espacement";			// distance in % of brush diameter at wich brush
														// shapes will be put into the bitmap along the
														// line of a stroke,
														// ! also used for Text tool (spacing between chars)
	strings[MIN_SPACING]		= "esp. mini";		// property label (keep short), not yet used
	strings[DYN_SPACING]		= "esp. dyn";		// property label (keep short), not yet used
	strings[SUBPIXELS]			= "Subpixel";			// allow subpixel precise positioning of tools
	strings[SOLID]				= "Trait plein";
	strings[BLUR_RADIUS]		= "Rayon";		// property label (keep short), also used for Dispersion filter
	// translate options
	strings[X_LABEL]			= "X";
	strings[Y_LABEL]			= "Y";
	strings[X_SCALE]			= "Echelle en X";
	strings[Y_SCALE]			= "Echelle en Y";
	strings[TRANSLATION_X]		= "X";
	strings[TRANSLATION_Y]		= "Y";
	strings[SCALE_X]			= "X";
	strings[SCALE_Y]			= "Y";
	strings[ANGLE]				= "Angle";

	strings[X_OFFSET]			= "Décal. X";
	strings[Y_OFFSET]			= "Décal. Y";
	// crop options
	strings[LEFT]				= "Gauche";
	strings[TOP]				= "Haut";
	// bucket fill options
	strings[TOLERANCE]			= "Tolérance";
	strings[SOFTNESS]			= "Souplesse";
	// shape options
	strings[PATH]				= "Ligne";				// property label
	strings[OUTLINE]			= "Ligne";
	strings[TRANSFORM]			= "Transform";
	strings[CLOSED]				= "Fermé";				// ie first and last point of path
														// are connected
	strings[CIRCLE]				= "Cercle";				// not yet used
	strings[RECT]				= "Rect";				// not yet used
	strings[ROUND_CORNERS]		= "Bords arrondis";		// not yet used
	// text options
	strings[FONT]				= "Police";
	strings[SIZE]				= "Taille";
	strings[ROTATION]			= "Rotation";
	strings[TEXT_INPUT]			= "Texte";				// label for text input control (not used anymore)
	strings[ADVANCE_SCALE]		= "Espacement";			// additional spacing between chars
														// (not used anymore)
	strings[HINTING]			= "align.";			// not used, hinting means that the shapes
														// of chars are modified to more directly
														// hit pixels
	strings[TEXT_LINE_SPACING]	= "Interligne";		// font height * line spacing = vertical line dist
	// color picker tool
	strings[TIP_SIZE]			= "Taille de la pipette";
	strings[PIXEL_1x1]			= "1x1 pixels";
	strings[PIXEL_3x3]			= "3x3 pixels";
	strings[PIXEL_5x5]			= "5x5 pixels";
	strings[INCLUDE_ALL_LAYERS]	= "Dans tout les calques";
	// tools
	strings[BRUSH]				= "Pinceau";
	strings[CLONE]				= "Tampon";				// clone brush (transfers parts of an image to
														// another place)
	strings[ERASER]				= "Gomme";
	strings[PEN]				= "Crayon";
	strings[PEN_ERASER]			= "Effaceur";
	strings[RESTORE]			= "Restaurer";			// opposite of eraser (restores alpha channel)
	strings[DROPPER]			= "Pipette";			// color picker
	strings[TEXT]				= "Texte";
	strings[BLUR]				= "Flou";
	strings[BITMAP]				= "Bitmap";
	strings[SELECT]				= "Selection";
	strings[TRANSLATE]			= "Déplacement";
	strings[CROP]				= "Découper";
	strings[BUCKET_FILL]		= "Pot de peinture";
	strings[SHAPE]				= "Forme";
	// zoom
	strings[ZOOM_IN]			= "Zoom avant";			// tool tips
	strings[ZOOM_OUT]			= "Zoom arrière";
	// actions
	strings[ADD_LAYER]			= "le nouveau calque";	// the following strings are for display in the
														// undo/redo menu
	strings[REMOVE_LAYER]		= "la suppression du calque";		// a "modifier" is a step of changing the bitmap,
														// ie a brush stroke or something else.
	strings[REMOVE_LAYERS]		= "la suppression des calques";
	strings[MOVE_LAYER]			= "le mouvement du calque";			// ie drag sorting to another pos in list
	strings[MOVE_LAYERS]		= "le mouvement des calques";
	strings[MERGE_LAYERS]		= "la combination des calques";
	strings[UNKOWN_MODIFIER]	= "le document incinnu";
	strings[ADD_MODIFIER]		= "l'ajout d'un objet";
	strings[ADD_MODIFIERS]		= "l'ajout des objets";
	strings[CHANGE_COLOR]		= "le changement de couleur";
	strings[CHANGE_COLORS]		= "le changement des couleurs";
	strings[REMOVE_MODIFIER]	= "la suppression de l'objet";
	strings[REMOVE_MODIFIERS]	= "la suppression des objets";
	strings[MOVE_MODIFIER]		= "l'emplacement de l'objet";
	strings[MOVE_MODIFIERS]		= "l'emplacement des objets";
	strings[TRANSLATE_MODIFIER]	= "le déplacement de l'objet";
	strings[TRANSLATE_MODIFIERS]	= "le déplacement des objets";
	strings[CHANGE_LAYER_SETTINGS]	= "les modifications du calque";
	strings[CROP_CANVAS]		= "la découpe du document";
	strings[RESIZE_CANVAS]		= "le redimensionnement du document";
	strings[ROTATE_CANVAS]		= "la rotation du document";
	strings[INSERT_CANVAS]		= "l'ajout d'un document";
	strings[CHANGE_OPACITY]		= "le changement d'opacité";
	strings[EDIT_MODIFIER]		= "l'édition des objets";
	// pasting properties
	strings[PASTE_PROPERTY]		= "la copie de la propriété";				// paste one property to one object
	strings[PASTE_PROPERTIES]	= "la copie des propriétés";			// paste multiple properties to one object
	strings[MULTI_PASTE_PROPERTY] = "la copie multiple de la propriété";		// paste one property to multiple objects
	strings[MUTLI_PASTE_PROPERTIES] = "la copie multiple des propriétés";	// paste multiple property to multiple objects
	// shape tool history
	strings[ADD_CONTROL_POINT]	= "l'ajout d'une poignée";
	strings[TOGGLE_OUTLINE]		= "le passage en ligne";
	strings[CHANGE_OUTLINE_WIDTH] = "le changement d'épaisseur de la ligne";
	strings[MODIFY_CONTROL_POINT] = "le changement du point de controle";
	strings[CLOSE_PATH_ACTION]	= "la fermeture de ligne";
	strings[INSERT_CONTROL_POINT] = "l'insertion d'un point de controle";
	strings[REMOVE_CONTROL_POINT] = "la suppression d'un point de controle";
	strings[CHANGE_POINT_SELECTION] = "le changement de sélection";
	// text tool history
	strings[CHANGE_FONT_SIZE]	= "la taille du texte";
	strings[CHANGE_TEXT_ROTATION] = "la rotation du texte";
	strings[MOVE_TEXT]			= "le déplacement du texte";
	strings[CHANGE_FONT]		= "le changement de police";
	strings[CHANGE_TEXT]		= "la modification du texte";
	strings[CHANGE_FONT_ADVANCE_SCALE] = "le changement de l'espacement";
	// crop tool
	strings[MODIFY_CROP_RECT]	= "la modification de la taille de découpe";
	// select tool
	strings[MODIFY_SELECT_RECT]	= "la modification de la taille de la sélection";
	// transformations
	strings[TRANSFORMATION]		= "la transformation";
	strings[BEGIN_TRANSFORMATION] = "le début de la transformation";
	strings[FINNISH_TRANSFORMATION]	= "la fin de la transformation";
	strings[MOVE]				= "le déplacement";
	strings[ROTATE]				= "la rotation";
	strings[SCALE]				= "l'echelle";
	strings[MOVE_PIVOT]			= "le mouvement du pivot";
	strings[TRANSFORM_OBJECT]	= "la transformation de l'objet";
	strings[TRANSFORM_OBJECTS]	= "la transformation des objets";
	// general
	strings[OK]					= "Ok";
	strings[CONFIRM]			= "Confirmer";			// apply changes
	strings[CANCEL]				= "Annuler";
	strings[REVERT]				= "Rétablir";				// revert changes made in panel
	strings[NAME]				= "Nom";				// name of project
	strings[UNNAMED]			= "Sans-titre";
	strings[DEFAULT]			= "Défaut";
	strings[MERGED]				= "Combiné";				// default name for merged layer
	strings[TOOL]				= "Outil";				// for tool tips
	strings[ANY_MODIFIER]		= "touche action";		// as in modifier key on the keyboard (shift,
														// option, alt etc)
	strings[RETURN]				= "Entrée";
	strings[ESCAPE]				= "Escape";
	strings[SET]				= "Groupe de pinceaux";
	// panels
	strings[PICK_COLOR]			= "Palette de couleur";			// window title of color picker
	strings[WIDTH]				= "Largeur";				// pixel count
	strings[HEIGHT]				= "Hauteur";
	strings[BRUSH_PANEL]		= "Liste des pinceaux";
	strings[BRUSH_NAME]			= "Nom du pinceau";
	strings[PROGRAM_SETTINGS]	= "Paramètres du logiciel";
	// program settings
	strings[ON_STARTUP]			= "Au démarrage";
	strings[DO_NOTHING]			= "Ne rien faire";
	strings[ASK_OPEN]			= "Demander le fichier à ouvrir";
	strings[ASK_NEW]			= "Ouvrir Nouveau document";
	strings[AUTO_SIZE]			= "Créer un nouveau document aux dimensions"B_UTF8_ELLIPSIS;
	strings[LIVE_UPDATES]		= "Actions visibles en temps réel dans l'espace de travail et icones des calques";
	strings[STARTUP_ACTION]		= "Actions au démarrage";
	strings[INTERFACE]			= "Interface";
	// requestors
	strings[AKS_SAVE_CHANGES]	= "Fermer le document sans enregister les changements ?";
	strings[DISCARD]			= "Ne rien enregister";
	strings[SAVE]				= "Enregistrer";
	strings[SAVING_FAILED]		= "L'enregistrement à échoué!";
	strings[ERROR]				= "Erreur";				// alias reason for above
	strings[BLIP]				= "Bi****p !";				// As in "Mission Earth"

	strings[DEMO_MODE]			= "WonderBrush est actuellement en mode demo. "
								  "L'enregistrement est désactivé.\n\n"
								  "Veuillez vous enregistrer sur the Kagi online store afin de recevoir"
								  "votre clé logiciel.";
	strings[NEVER_MIND]			= "Désolé";
	strings[OPEN_TRANSLATIONKIT_ERROR]	= "Erreur lors de l´ouverture de '%s' en utilisant "
								  "le Translation Kit.\n\nOu ce fichier ne "
								  "contient pas d´image, ou le Translator "
								  "de ce fomat d´image n´est pas installé "
								  "sur votre système.";
	strings[OPEN_NATIVE_ERROR]	= "Erreur lors de l´ouverture du fichier '%s' en tant "
								  "que fichier WonderBrush.\n\n";		// yes, that's two \n
	strings[UNSUPPORTED_CURSOR_SIZE] = "Le projet doit faire 16px par 16px. "
								  "Toute autre taille en sera pas supporté ";
	strings[SELECTED_AREA_EMPTY] = "La selection est vide.";
	// tool tips										// please test the appearance of the tips and
														// try to align them manually by putting the
														// '\n' in the right spot!

	strings[TOOL_TIPS]			= "Afficher les infobulles";
	strings[ALPHA_TIP]			= "Réglage de la transparence du calque sélectionné.";
	strings[VISIBILITY_TIP]		= "Calque visible/invisible";
	strings[PRESSURE_CONTROL_TIP]	= "Activer le controle du la pression pour les tablettes.";
	strings[BRUSH_PREVIEW_TIP]	= "Apercu du pinceau. Cliquez pour ouvrir la liste des pinceaux.";
	strings[CURRENT_COLOR_TIP]	= "Apercu de la couleur. Cliquez pour ouvrir la palette de couleurs.";
	strings[NAVIGATOR_TIP]		= "Apercu de l'espace de travail. Cliquez/déposer pour faire glisser la zone d´affichage.\n"
								  "Utilisez la molette pour zoomer.";
	strings[LAYER_LIST_TIP]		= "Organiser par glisser/déposer. Cliquez sur l´oeil pour le rendre\n"
								  "visible/invisible. Double clic pour changer le nom.";
	strings[HISTORY_LIST_TIP]	= "Organiser par glisser/déposer. Glissez/déposez une couleur\n"
								  "pour changer la couleur du modifieur.";
	strings[PROPERTY_LIST_TIP]	= "Editer, copier et coller les propriétés de l´objet.";
	strings[SUB_PIXEL_TIP]		= "Déplacer vos objets au subpixel près.";
	strings[SOLID_TIP]			= "Ne pas varier l´opacité par pixel.";
	strings[FULLSCREEN_TIP]		= "Passer en mode plein écran/fenétré.";
	// quick help
	strings[READY]				= "Pret.";
	strings[NO_CANVAS_HELP]		= "Creer un nouveau document ou projet ou image.";
	strings[NO_HELP]			= "Pas d´astuce.";
	strings[CROP_HELP]			= "Ajuster le rectangle de sélection, appuyer sur <Entrée> pour appliquer. <Shift> pour restreindre le rectangle à un carré.";
	strings[TRANSLATE_HELP]		= "Selectionnez les objets à déplacer. <Shift> pour restreindre le déplacement.";
	strings[STROKE_HELP]		= "Utilisez <Shift> pour étendre le trait et finir la ligne.";
	strings[CLONE_HELP]			= "Le premier clic défini le chemin de l´image, le second le décalage. Appuyer sur <Ctrl> pour annuler le décalage.";
	strings[BUCKET_FILL_HELP]	= "\"Softness\" controle la dureté de la couleur sélectionnée.";
	strings[TEXT_HELP]			= "Appuyer sur <Entrée> lorsque vous désirez appliquer les modifications.";
	strings[SHAPE_HELP]			= "Gardez appuyé <Command> ou <Alt> pour plus d´options. Appuyer sur <Entrée> pour terminer.";
	strings[SELECT_HELP]		= "Selectionner une zone à copier.";

}
